@@ -4,7 +4,6 @@ can be used as a standalone window or in a larger GUI.
 """
 
 import sys
-import time
 import ctypes
 import importlib
 
@@ -55,33 +54,22 @@ def enable_hidpi():
 enable_hidpi()
 
 
-class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
-    """A Qt widget providing a wgpu canvas."""
+class QWgpuWidget(WgpuCanvasBase, QtWidgets.QWidget):
+    """A QWidget representing a wgpu canvas that can be embedded in a Qt application."""
 
     def __init__(self, *args, size=None, title=None, **kwargs):
         super().__init__(*args, **kwargs)
 
         if size:
-            width, height = size
-            self.resize(width, height)
-        elif "parent" not in kwargs:
-            self.resize(640, 480)
+            self.resize(*size)
         if title:
             self.setWindowTitle(title)
 
-        # The actual surface is held by a subwidget. This is to make sure that
-        # the logical surface size is actually integer. Otherwise the window
-        # size can be set to subpixel (logical) values, without being able to
-        # detect this. See https://github.com/pygfx/wgpu-py/pull/68
-        self._subwidget = WgpuSubWidget(self)
-
-        layout = QtWidgets.QHBoxLayout(self)
-        layout.setContentsMargins(0, 0, 0, 0)
-        self.setLayout(layout)
-        layout.addWidget(self._subwidget)
+        # Configure how Qt renders this widget
+        self.setAttribute(WA_PaintOnScreen, True)
+        self.setAutoFillBackground(False)
 
         # A timer for limiting fps
-        self._target_fps = 30  # subclasses could edit this value
         self._request_draw_timer = QtCore.QTimer()
         self._request_draw_timer.setTimerType(PreciseTimer)
         self._request_draw_timer.setSingleShot(True)
@@ -92,6 +80,85 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
         # one does not provide canvas to request_adapter().
         self.get_window_id()
 
+    def paintEngine(self):  # noqa: N802 - this is a Qt method
+        # https://doc.qt.io/qt-5/qt.html#WidgetAttribute-enum  WA_PaintOnScreen
+        return None
+
+    def paintEvent(self, event):  # noqa: N802 - this is a Qt method
+        self._draw_frame_and_present()
+
+    # Methods that we add from wgpu (snake_case)
+
+    def get_display_id(self):
+        # There is qx11info, but it is rarely available.
+        # https://doc.qt.io/qt-5/qx11info.html#display
+        return super().get_display_id()  # uses X11 lib
+
+    def get_window_id(self):
+        return int(self.winId())
+
+    def get_pixel_ratio(self):
+        # Observations:
+        # * On Win10 + PyQt5 the ratio is a whole number (175% becomes 2).
+        # * On Win10 + PyQt6 the ratio is correct (non-integer).
+        return self.devicePixelRatioF()
+
+    def get_logical_size(self):
+        # Sizes in Qt are logical
+        lsize = self.width(), self.height()
+        return float(lsize[0]), float(lsize[1])
+
+    def get_physical_size(self):
+        # https://doc.qt.io/qt-5/qpaintdevice.html
+        # https://doc.qt.io/qt-5/highdpi.html
+        lsize = self.width(), self.height()
+        lsize = float(lsize[0]), float(lsize[1])
+        ratio = self.devicePixelRatioF()
+        # When the ratio is not integer (qt6), we need to somehow round
+        # it. It turns out that we need to round it, but also add a
+        # small offset. Tested on Win10 with several different OS
+        # scales. Would be nice if we could ask Qt for the exact
+        # physical size! Not an issue on qt5, because ratio is always
+        # integer then.
+        return round(lsize[0] * ratio + 0.01), round(lsize[1] * ratio + 0.01)
+
+    def set_logical_size(self, width, height):
+        if width < 0 or height < 0:
+            raise ValueError("Window width and height must not be negative")
+        self.resize(width, height)  # See comment on pixel ratio
+
+    def _request_draw(self):
+        if not self._request_draw_timer.isActive():
+            self._request_draw_timer.start(self._get_draw_wait_time() * 1000)
+
+    def close(self):
+        super().close()
+
+    def is_closed(self):
+        return not self.isVisible()
+
+
+class QWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
+    """A toplevel Qt widget providing a wgpu canvas."""
+
+    # Most of this is proxying stuff to the inner widget.
+    # We cannot use a toplevel widget directly, otherwise the window
+    # size can be set to subpixel (logical) values, without being able to
+    # detect this. See https://github.com/pygfx/wgpu-py/pull/68
+
+    def __init__(self, *, size=None, title=None, max_fps=30, **kwargs):
+        super().__init__(**kwargs)
+
+        self.set_logical_size(*(size or (640, 480)))
+        self.setWindowTitle(title or "qt wgpu canvas")
+
+        self._subwidget = QWgpuWidget(self, max_fps=max_fps)
+
+        layout = QtWidgets.QHBoxLayout(self)
+        layout.setContentsMargins(0, 0, 0, 0)
+        self.setLayout(layout)
+        layout.addWidget(self._subwidget)
+
         self.show()
 
     # Qt methods
@@ -103,49 +170,27 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
     # Methods that we add from wgpu (snake_case)
 
     def get_display_id(self):
-        # There is qx11info, but it is rarely available.
-        # https://doc.qt.io/qt-5/qx11info.html#display
-        return super().get_display_id()  # uses X11 lib
+        return self._subwidget.get_display_id()
 
     def get_window_id(self):
-        return int(self._subwidget.winId())
+        return self._subwidget.get_window_id()
 
     def get_pixel_ratio(self):
-        # Observations:
-        # * On Win10 + PyQt5 the ratio is a whole number (175% becomes 2).
-        # * On Win10 + PyQt6 the ratio is correct (non-integer).
-        return self._subwidget.devicePixelRatioF()
+        return self._subwidget.get_pixel_ratio()
 
     def get_logical_size(self):
-        # Sizes in Qt are logical
-        lsize = self._subwidget.width(), self._subwidget.height()
-        return float(lsize[0]), float(lsize[1])
+        return self._subwidget.get_logical_size()
 
     def get_physical_size(self):
-        # https://doc.qt.io/qt-5/qpaintdevice.html
-        # https://doc.qt.io/qt-5/highdpi.html
-        lsize = self._subwidget.width(), self._subwidget.height()
-        lsize = float(lsize[0]), float(lsize[1])
-        ratio = self._subwidget.devicePixelRatioF()
-        # When the ratio is not integer (qt6), we need to somehow round
-        # it. It turns out that we need to round it, but also add a
-        # small offset. Tested on Win10 with several different OS
-        # scales. Would be nice if we could ask Qt for the exact
-        # physical size! Not an issue on qt5, because ratio is always
-        # integer then.
-        return round(lsize[0] * ratio + 0.01), round(lsize[1] * ratio + 0.01)
+        return self._subwidget.get_physical_size()
 
     def set_logical_size(self, width, height):
         if width < 0 or height < 0:
             raise ValueError("Window width and height must not be negative")
-        self.resize(width, height)  # See note on pixel ratio below
+        self.resize(width, height)  # See comment on pixel ratio
 
     def _request_draw(self):
-        if not self._request_draw_timer.isActive():
-            now = time.perf_counter()
-            target_time = self._subwidget._draw_time + 1 / self._target_fps
-            wait_time = max(0, target_time - now)
-            self._request_draw_timer.start(wait_time * 1000)
+        return self._subwidget._request_draw()
 
     def close(self):
         super().close()
@@ -153,24 +198,15 @@ class QtWgpuCanvas(WgpuCanvasBase, QtWidgets.QWidget):
     def is_closed(self):
         return not self.isVisible()
 
+    # Methods that we need to explicitly delegate to the subwidget
 
-class WgpuSubWidget(QtWidgets.QWidget):
-    """The widget that actually provides the surface to render to."""
+    def get_context(self, *args, **kwargs):
+        return self._subwidget.get_context(*args, **kwargs)
 
-    def __init__(self, parent):
-        super().__init__(parent)
-        self.setAttribute(WA_PaintOnScreen, True)
-        self.setAutoFillBackground(False)
-        self._draw_time = 0
-
-    def paintEngine(self):  # noqa: N802 - this is a Qt method
-        # https://doc.qt.io/qt-5/qt.html#WidgetAttribute-enum  WA_PaintOnScreen
-        return None
-
-    def paintEvent(self, event):  # noqa: N802 - this is a Qt method
-        self._draw_time = time.perf_counter()
-        self.parent()._draw_frame_and_present()
+    def request_draw(self, *args, **kwargs):
+        return self._subwidget.request_draw(*args, **kwargs)
 
 
 # Make available under a name that is the same for all gui backends
-WgpuCanvas = QtWgpuCanvas
+WgpuWidget = QWgpuWidget
+WgpuCanvas = QWgpuCanvas
